unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  IconImage, IconLibrary, StdCtrls, ExtCtrls, ShellApi, Menus, IconTools,
  AdvancedIcon;   

type
  TForm1 = class(TForm)
    LIBListBox: TListBox;
    ICOOpenDialog: TOpenDialog;
    LIBOpenDialog: TOpenDialog;
    ICOSaveDialog: TSaveDialog;
    LIBSaveDialog: TSaveDialog;
    MainMenu1: TMainMenu;
    MenuFile: TMenuItem;
    LoadICO: TMenuItem;
    SaveICO: TMenuItem;
    N1: TMenuItem;
    LoadLIB: TMenuItem;
    SaveLIB: TMenuItem;
    Panel: TPanel;
    ButtonSaveIcon: TButton;
    ButtonLoadIcon: TButton;
    ButtonLoadLibrary: TButton;
    ButtonSaveLibrary: TButton;
    ButtonClearLibrary: TButton;
    Button1: TButton;
    ButtonDeleteLIBIcon: TButton;
    PanelIcon: TPanel;
    ICOListBox: TListBox;
    ICOCountLabel: TPanel;
    LIBNameLabel: TPanel;
    ButtonDeleteIconImage: TButton;
    ButtonSizeSort: TButton;
    ButtonColorSort: TButton;
    DoChange: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure LoadLIBClick(Sender: TObject);
    procedure LIBListBoxClick(Sender: TObject);
    procedure ICOListBoxDrawItem(Control: TWinControl; Index: Integer;
      Rect: TRect; State: TOwnerDrawState);
    procedure LoadICOClick(Sender: TObject);
    procedure ButtonSaveIconClick(Sender: TObject);
    procedure SaveLIBClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure ICOListBoxMeasureItem(Control: TWinControl; Index: Integer;
      var Height: Integer);
    procedure ButtonClearLibraryClick(Sender: TObject);
    procedure ButtonDeleteLIBIconClick(Sender: TObject);
    procedure ButtonDeleteIconImageClick(Sender: TObject);
    procedure ButtonSizeSortClick(Sender: TObject);
    procedure ButtonColorSortClick(Sender: TObject);
    procedure Button1Click(Sender: TObject);
  private
    { Private declarations }
  public
    Icon : TAdvancedIcon;
    IconLib : TIconLibrary;
    P : Pointer;
    procedure LibraryLoaded;
    procedure IconLoaded;
    procedure LIBIconSelected;
    procedure ApplyChanges;
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}
{$R Icons.res}

procedure TForm1.FormCreate(Sender: TObject);
begin
  Icon:=TAdvancedIcon.Create;
  IconLib:=TIconLibrary.Create;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  Icon.Free;
  IconLib.free;
end;

procedure TForm1.LibraryLoaded;
begin
  LIBListBox.Items.assign(IconLib.Icons);
  LibNameLabel.caption:=' Library: '+IconLib.Filename;
  IF LIBListBox.Items.Count>0 Then begin
    LIBListBox.ItemIndex:=0;
    LibIconSelected;
  end;
end;

procedure TForm1.IconLoaded;
Var
  I : Integer;
  Image : TIconImage;
begin
  With ICOListBox Do begin
    Items.Clear;
    ICOCountLabel.Caption:=Format('Number of Subicons: %d',[Icon.Images.Count]);
    Items.BeginUpdate;
    try
      FOR I:=1 TO Icon.Images.Count DO begin
        Image:=Icon.Images.Image[I-1];
        Items.AddObject(InttoStr(I),Image);
      end;
    finally
      Items.EndUpdate;
    end;
    IF Items.Count>0 Then ICOListBox.ItemIndex:=0;
  end;
end;

procedure TForm1.ApplyChanges;
Var
  I : TAdvancedIcon;
begin
  IF NOT DoChange.Checked then exit;
  With LIBListBox do begin
    IF (ItemIndex<0) OR (ItemIndex>=IconLib.Icons.Count) then exit;
    I:=TAdvancedIcon(Items.Objects[ItemIndex]);
    I.Assign(Icon);
  end;  
end;

procedure TForm1.LIBIconSelected;
Var
  I : TAdvancedIcon;
begin
  IF LIBListBox.ItemIndex<0 then exit;
  I:=TAdvancedIcon(LIBListBox.Items.Objects[LIBListBox.ItemIndex]);
  IF NOT Assigned(I) Then exit;
  IF NOT (I is TAdvancedIcon) Then exit;
  Icon.Assign(I);
  IconLoaded;
end;

procedure TForm1.LIBListBoxClick(Sender: TObject);
begin
  LIBIconSelected;
end;

procedure TForm1.ICOListBoxMeasureItem(Control: TWinControl; Index: Integer; var Height: Integer);
Var
  Image : TIconImage;
begin
  With ICOListBox DO begin
    IF Index<0 Then exit;
    IF Index>=Icon.Images.Count Then exit;
    Image:=Icon.Images.Image[Index];
    IF NOT Assigned(Image) then exit;
    IF NOT (Image is TIconImage) Then exit;
  end;
  Height:=Image.Info.Height+4;
end;

procedure TForm1.ICOListBoxDrawItem(Control: TWinControl; Index: Integer;
  Rect: TRect; State: TOwnerDrawState);
Var
  S : String;
  Image : TIconImage;
begin
  With ICOListBox DO begin
    IF Index<0 Then exit;
    IF Index>=Icon.Images.Count Then exit;
    Image:=Icon.Images.Image[Index];
    IF NOT Assigned(Image) then exit;
    IF NOT (Image is TIconImage) Then exit;
    With Canvas DO begin
      With Image.Info DO begin
        FillRect(Rect);
        IF rect.Left=0 Then Image.Draw(Canvas,Rect.Left+((60-Width)DIV 2),Rect.Top+2);
        S:=(Control as TListBox).Items[Index];
        TextOut(Rect.Left+100, Rect.Top+2+((Height-TextExtent(S).cy) DIV 2),S);
//        IF (odSelected in State) Then InvertRect(Canvas.Handle,Classes.Rect(Rect.Left+H+2,Rect.Top,Rect.Right,Rect.Bottom) );
      end;
    end;
  end;
end;

procedure TForm1.LoadICOClick(Sender: TObject);
begin
  IF NOT ICOOpenDialog.Execute Then exit;
  Icon.LoadFromFile(ICOOpenDialog.Filename);
  IconLib.Icons.Clear;
  LibraryLoaded;
  IconLoaded;
end;

procedure TForm1.ButtonSaveIconClick(Sender: TObject);
begin
  IF Icon.Images.Count=0 Then exit;
  IF NOT ICOSaveDialog.Execute Then exit;
  Icon.SaveToFile(ICOSaveDialog.Filename);
end;

procedure TForm1.LoadLIBClick(Sender: TObject);
begin
  IF NOT LIBOpenDialog.Execute Then exit;
  IconLib.LoadFromFile(LIBOpenDialog.Filename);
  LibraryLoaded;
  LIBListBox.Enabled:=True;
end;

procedure TForm1.SaveLIBClick(Sender: TObject);
begin
  IF IconLib.Icons.Count=0 Then exit;
  IF NOT LIBSaveDialog.Execute Then exit;
  IconLib.SaveToFile(LIBSaveDialog.Filename);
end;

procedure TForm1.FormShow(Sender: TObject);
begin
  IconLib.LoadSelf;
  LibraryLoaded;
end;



procedure TForm1.ButtonClearLibraryClick(Sender: TObject);
begin
  IconLib.Icons.Clear;
  Icon.Images.Clear;
  LibraryLoaded;
  IconLoaded;
end;

procedure TForm1.ButtonDeleteLIBIconClick(Sender: TObject);
begin
  With LIBListBox DO begin
    IF (ItemIndex<0) OR (ItemIndex>IconLib.Icons.Count) Then exit;
    IconLib.Icons.Delete(ItemIndex);
    LibraryLoaded;
  end;  
end;


procedure TForm1.ButtonDeleteIconImageClick(Sender: TObject);
begin
  With ICOListBox DO begin
    IF (ItemIndex<0) OR (ItemIndex>Icon.Images.Count) OR (Icon.Images.Count<=1) Then exit;
    Icon.Images.Delete(ItemIndex);
    IconLoaded;
  end;  
  ApplyChanges;
end;



procedure TForm1.ButtonSizeSortClick(Sender: TObject);
begin
  Icon.Images.SortByResolution;
  IconLoaded;
  ApplyChanges;
end;

procedure TForm1.ButtonColorSortClick(Sender: TObject);
begin
  Icon.Images.SortByColor;
  IconLoaded;
  ApplyChanges;
end;

procedure TForm1.Button1Click(Sender: TObject);
Var
 Icon : TAdvancedIcon;
begin
  IF NOT ICOOpenDialog.Execute Then exit;
  Icon:=TAdvancedicon.Create;
  Icon.LoadFromFile(ICOOpenDialog.Filename);
  IconLib.Icons.addIcon('',Icon);
  LibraryLoaded;
end;

end.
